MpfrInput

Trait MpfrInput 

pub trait MpfrInput {
    // Required methods
    fn to_bigfloat(&self, bits: u64) -> BigFloat;
    fn to_bigfloat_digits(&self, digits: u32) -> BigFloat;
}
Trait for types that can be converted into a BigFloat.

This is implemented for &str and f64, allowing the free arithmetic and mathematical functions to accept both numeric string literals and native floats as arguments.

Required Methods

fn to_bigfloat(&self, bits: u64) -> BigFloat

Converts the value to a BigFloat with the given bit‑precision.

fn to_bigfloat_digits(&self, digits: u32) -> BigFloat

Converts the value to a BigFloat with a precision sufficient for digits decimal digits.

Implementations on Foreign Types

Source

impl MpfrInput for &str

Source

fn to_bigfloat(&self, bits: u64) -> BigFloat

Source

fn to_bigfloat_digits(&self, digits: u32) -> BigFloat

Source

impl MpfrInput for f64

Source

fn to_bigfloat(&self, bits: u64) -> BigFloat

Source

fn to_bigfloat_digits(&self, digits: u32) -> BigFloat

Implementors